@@ -372,7 +372,7 @@ public:
             m_lastpos = ipos;
         bool noexpand = be ? m_ts->nostemexp() : true;
         LOGDEB1("TermProcQ::takeword: pushing [" << term << "] pos " <<
-                pos << " noexp " << noexpand << "\n");
+                ipos << " noexp " << noexpand << "\n");
         if (m_terms[ipos].size() < term.size()) {
             m_terms[ipos] = term;
             m_nste[ipos] = noexpand;
@@ -932,6 +932,8 @@ bool SearchDataClauseSimple::toNativeQuery(Rcl::Db &db, void *p)
     LOGDEB("SearchDataClauseSimple::toNativeQuery: fld [" << m_field <<
            "] val [" << m_text << "] stemlang [" << getStemLang() << "]\n");
 
+    m_hldata.clear();
+
     // Transform (in)equalities into a range query
     switch (getrel()) {
     case REL_EQUALS:
@@ -974,8 +976,12 @@ bool SearchDataClauseSimple::toNativeQuery(Rcl::Db &db, void *p)
 
     vector<Xapian::Query> pqueries;
     std::string pbterm;
-    if (!processUserString(db, m_text, m_reason, pbterm, &pqueries))
+    if (m_text.empty()) {
+        // Simpler to just special-case the empty case here.
+        pqueries = std::vector<Xapian::Query>{Xapian::Query(std::string())};
+    } else if (!processUserString(db, m_text, m_reason, pbterm, &pqueries)) {
         return false;
+    }
     if (pqueries.empty()) {
         LOGDEB("SearchDataClauseSimple: " << m_text << " resolved to null query\n");
         if (!pbterm.empty()) 
@@ -998,6 +1004,9 @@ bool SearchDataClauseRange::toNativeQuery(Rcl::Db &db, void *p)
 {
     LOGDEB("SearchDataClauseRange::toNativeQuery: " << m_field <<
            " :[" << m_text << ".." << m_t2 << "]\n");
+
+    m_hldata.clear();
+
     Xapian::Query *qp = (Xapian::Query *)p;
     *qp = Xapian::Query();
 
@@ -1021,8 +1030,8 @@ bool SearchDataClauseRange::toNativeQuery(Rcl::Db &db, void *p)
     string errstr;
     try {
         if (m_text.empty()) {
-            *qp = Xapian::Query(Xapian::Query::OP_VALUE_LE,
-                                ftp->valueslot, convert_field_value(*ftp, m_t2));
+            *qp = Xapian::Query(Xapian::Query::OP_VALUE_LE, ftp->valueslot,
+                                convert_field_value(*ftp, m_t2));
         } else if (m_t2.empty()) {
             *qp = Xapian::Query(Xapian::Query::OP_VALUE_GE, ftp->valueslot,
                                 convert_field_value(*ftp, m_text));
@@ -1053,6 +1062,8 @@ bool SearchDataClauseRange::toNativeQuery(Rcl::Db &db, void *p)
 // file names
 bool SearchDataClauseFilename::toNativeQuery(Rcl::Db &db, void *p)
 {
+    m_hldata.clear();
+
     Xapian::Query *qp = (Xapian::Query *)p;
     *qp = Xapian::Query();
 
@@ -1074,6 +1085,9 @@ bool SearchDataClauseFilename::toNativeQuery(Rcl::Db &db, void *p)
 bool SearchDataClausePath::toNativeQuery(Rcl::Db &db, void *p)
 {
     LOGDEB("SearchDataClausePath::toNativeQuery: [" << m_text << "]\n");
+
+    m_hldata.clear();
+    
     Xapian::Query *qp = (Xapian::Query *)p;
     *qp = Xapian::Query();
 
@@ -1132,6 +1146,8 @@ bool SearchDataClauseDist::toNativeQuery(Rcl::Db &db, void *p)
 {
     LOGDEB("SearchDataClauseDist::toNativeQuery\n");
 
+    m_hldata.clear();
+
     Xapian::Query *qp = (Xapian::Query *)p;
     *qp = Xapian::Query();
 
@@ -1145,7 +1161,7 @@ bool SearchDataClauseDist::toNativeQuery(Rcl::Db &db, void *p)
     string s = cstr_dquote + m_text + cstr_dquote;
     bool useNear = (m_tp == SCLT_NEAR);
     if (!useNear  && !o_expand_phrases && !(m_modifiers & SDCM_EXPANDPHRASE)) {
-        // We are a phrase query. Make sure to disable stemming explicitely in case this is a single
+        // We are a phrase query. Make sure to disable stemming explicitly in case this is a single
         // quoted word because processUserString won't see it as a phrase by itself.
         m_modifiers |= SDCM_NOSTEMMING;
     }
